@@ -53,7 +53,7 @@ from univention.management.console.config import ucr
 from univention.management.console.modules import Base, UMC_Error
 from univention.management.console.modules.decorators import simple_response, sanitize, multi_response, prevent_xsrf_check, allow_get_request
 from univention.management.console.modules.sanitizers import (
-	Sanitizer, LDAPSearchSanitizer, EmailSanitizer, ChoicesSanitizer,
+	Sanitizer, SearchSanitizer, EmailSanitizer, ChoicesSanitizer,
 	ListSanitizer, StringSanitizer, DictSanitizer, BooleanSanitizer,
 	DNSanitizer
 )
@@ -74,7 +74,7 @@ import univention.directory.reports as udr
 
 from .udm_ldap import (
 	UDM_Error, UDM_Module,
-	ldap_dn2path, get_module, read_syntax_choices, list_objects, _get_syntax,
+	ldap_dn2path, get_module, get_obj_module, read_syntax_choices, list_objects, _get_syntax,
 	LDAP_Connection, set_bind_function, container_modules,
 	info_syntax_choices, search_syntax_choices_by_key,
 	UserWithoutDN, ObjectDoesNotExist, SuperordinateDoesNotExist, NoIpLeft,
@@ -141,7 +141,7 @@ class ObjectPropertySanitizer(StringSanitizer):
 		StringSanitizer.__init__(self, **args)
 
 
-class PropertySearchSanitizer(LDAPSearchSanitizer):
+class PropertySearchSanitizer(SearchSanitizer):
 
 	def _sanitize(self, value, name, further_arguments):
 		object_type = further_arguments.get('objectType')
@@ -223,6 +223,9 @@ class Instance(Base, ProgressMixin):
 	def get_module(self, flavor, ldap_dn):
 		return get_module(flavor, ldap_dn, self.get_ldap_connection()[0])
 
+	def get_obj_module(self, flavor, ldap_dn):
+		return get_obj_module(flavor, ldap_dn, self.get_ldap_connection()[0])
+
 	def _get_module_by_request(self, request, object_type=None):
 		"""Tries to determine the UDM module to use. If no specific
 		object type is given the request option 'objectType' is used. In
@@ -514,11 +517,10 @@ class Instance(Base, ProgressMixin):
 		for ldap_dn in request.options:
 			if request.flavor == 'users/self':
 				ldap_dn = self._user_dn
-			module = self.get_module(request.flavor, ldap_dn)
+			obj, module = self.get_obj_module(request.flavor, ldap_dn)
 			if module is None:
 				raise ObjectDoesNotExist(ldap_dn)
 			else:
-				obj = module.get(ldap_dn)
 				if obj:
 					_remove_uncopyable_properties(obj)
 					obj.set_defaults = True
@@ -589,10 +591,10 @@ class Instance(Base, ProgressMixin):
 				superordinate = None
 			elif superordinate is not None:
 				MODULE.info('Query defines a superordinate %s' % superordinate)
-				mod = self.get_module(request.flavor, superordinate)
+				_superordinate, mod = self.get_obj_module(request.flavor, superordinate)
 				if mod is not None:
 					MODULE.info('Found UDM module %r for superordinate %s' % (mod.name, superordinate))
-					superordinate = mod.get(superordinate)
+					superordinate = _superordinate
 					if not request.options.get('container'):
 						request.options['container'] = superordinate.dn
 				else:
@@ -604,7 +606,7 @@ class Instance(Base, ProgressMixin):
 			scope = request.options.get('scope', 'sub')
 			hidden = request.options.get('hidden')
 			fields = (set(request.options.get('fields', []) or []) | set([objectProperty])) - set(['name', 'None'])
-			result = module.search(container, objectProperty, objectPropertyValue, superordinate, scope=scope, hidden=hidden)
+			result = module.search(container, objectProperty, objectPropertyValue, superordinate, scope=scope, hidden=hidden, allow_asterisks=USE_ASTERISKS)
 			if result is None:
 				return []
 
@@ -936,7 +938,7 @@ class Instance(Base, ProgressMixin):
 
 	@sanitize(
 		syntax=StringSanitizer(required=True),
-		key=LDAPSearchSanitizer(use_asterisks=False),
+		key=SearchSanitizer(use_asterisks=False),
 	)
 	@simple_response
 	def syntax_choices_key(self, syntax, key):
@@ -971,7 +973,7 @@ class Instance(Base, ProgressMixin):
 		return info_syntax_choices(syntax, ldap_connection=lo, ldap_position=po)
 
 	@sanitize(
-		objectPropertyValue=LDAPSearchSanitizer(),
+		objectPropertyValue=SearchSanitizer(),
 		objectProperty=ObjectPropertySanitizer(),
 		syntax=StringSanitizer(required=True)
 	)
@@ -989,7 +991,15 @@ class Instance(Base, ProgressMixin):
 			syntax = _get_syntax(request.options['syntax'])
 			if syntax is None:
 				return
-			return read_syntax_choices(syntax, request.options, ldap_connection=ldap_connection, ldap_position=ldap_position)
+
+			options = request.options
+			options.pop('allow_asterisks', None)  # internal option
+			options['dependencies'] = {}
+			dependency_name = options.get('$depends$')
+			if options.get(dependency_name):
+				options['dependencies'] = {dependency_name: options.pop(dependency_name)}
+
+			return read_syntax_choices(syntax, options, ldap_connection=ldap_connection, ldap_position=ldap_position)
 
 		thread = notifier.threads.Simple('SyntaxChoice', notifier.Callback(_thread, request), notifier.Callback(self.thread_finished_callback, request))
 		thread.run()
